<!doctype html>
<html>
  <head>
    <title>Příklady PHP</title>
    <meta charset="UTF-8">
    <link rel="stylesheet" href="ukazky.css">
    <link rel="stylesheet" href="formulare.css">
  </head>
  <body>
  <div>
    <header>PHP administrace - databáze výrobky</header>
    <nav><?php include "menu.php"; ?></nav>
    <article>
    <h1>Upravení zvoleného záznamu</h1>
    <?php
    include 'spojeni.php'; // 1 - vytvoření objektu $spojeni a 2 - nastavení UTF-8

    if(!isset($_POST["ulozit"])) {  // 3 - zjištění zda byl odeslán formulář - metoda POST, ulozit je name odesílacího tlačítka
      // když $_POST["ulozit"] neexistuje - formulář ještě nebyl odeslán - načtení a zobrazení údajů do editačního formuláře
      // 3.1 - připravení dotazu s podmínkou pro id - načtení daného záznamu
      $dotaz=$spojeni->prepare("SELECT id_kategorie,id_vyrobce,nazev,cena,skladem,stav,popis FROM vyrobky WHERE vyrobky.id= ? LIMIT 1");
      $dotaz->bind_param("i",$_GET["id"]);  // 3.2 - přiřazení parametru $_GET["id"] do podmínky
      $dotaz->bind_result($eid_kategorie,$eid_vyrobce,$enazev,$ecena,$eskladem,$estav,$epopis); // 3.3 - přiřazení výstupních proměnných
      $dotaz->execute();  // 3.4 - spuštění dotazu
      $dotaz->fetch();    // 3.5 - načtení záznamu do výstupních proměnných - bez cyklu (1 záznam)
      $dotaz->close();    // 3.6 - uzavření dotazu
      // 3.7 - zobrazení editovaných údajú do formuláře
      ?>
      <form method="post" onsubmit="return kontrola()">
      <label>Kategorie</label>
      <select name="kategorie">
        <?php
          $dotaz=$spojeni->prepare("SELECT id,kategorie FROM kategorie ORDER BY kategorie");
          $dotaz->bind_result($id,$kategorie);
          $dotaz->execute();
          while($dotaz->fetch()) {
            if($eid_kategorie==$id) {echo "<option value='$id' selected>$kategorie</option>\n";}
            else {echo "<option value='$id'>$kategorie</option>\n";}
          }
          $dotaz->close();
        ?>
      </select><br>
      <label>Výrobce</label>
      <select name="vyrobce">
        <?php
          $dotaz=$spojeni->prepare("SELECT id,nazev FROM vyrobci ORDER BY nazev");
          $dotaz->bind_result($id,$nazev);
          $dotaz->execute();
          while($dotaz->fetch()) {
            //if($eid_vyrobce==$id) {echo "<option value='$id' selected>$nazev</option>\n";}
            //else {echo "<option value='$id'>$nazev</option>\n";}
            echo "<option value='$id' ".($eid_vyrobce==$id?"selected":"").">$nazev</option>\n";   //ternární operátor - totéž jako předchozí if
          }
          $dotaz->close();
        ?>
      </select><br>

      <label>Název výrobku</label><input type="text" name="nazev" maxlength="30" value="<?php echo $enazev; ?>"><br>
      <label>Cena bez DPH</label><input type="text" name="cena" value="<?php echo $ecena; ?>"><br>
      <label>Skladem</label><input type="checkbox" name="skladem" value="1" <?php if($eskladem==1) {echo "checked";} ?>><br>
      <label>Stav zboží</label><input type="radio" name="stav" value="n" <?php if($estav=="n") {echo "checked";} ?>> nové
                               <input type="radio" name="stav" value="o" <?php if($estav=="o") {echo "checked";} ?>> opravené
                               <input type="radio" name="stav" value="v" <?php if($estav=="v") {echo "checked";} ?>> vystavené<br>
      <label>Popis</label><br><textarea name="popis"><?php echo $epopis; ?></textarea><br>
      <input type="submit" name="ulozit" value="Uložit změny">
      </form>
      <p><a href="vypis_administrace.php">«&nbsp;zpět na výpis</a></p>
    <?php
    } // konec části 3
    else {  // 4 - $_POST["ulozit"] existuje - formulář byl odeslán
      // 4.1 - kontrola dat - prázdné povinné údaje nebo data neodpovídajícího formátu
      $zprava=""; //zůstane-li prázdná, můžou se data uložit
      //kategorii a výrobce nemusíme kontrolovat - v selectu není prázdná option
      if($_POST["nazev"]=="") {$zprava.="Nebyl zadán název. ";}
      //if($_POST["cena"]=="" || !is_numeric($_POST["cena"])) {$zprava.="Nebyla zadána cena - číslo. ";}
      //cenu můžeme zkontrolovat funkcí is_numeric nebo regulárním výrazem
      if(!preg_match("/^[0-9]{1,}$/",$_POST["cena"])) {$zprava.="Nebyla zadána cena - celé číslo. ";}
      if($zprava!="") {echo "<h3 class='chyba'>$zprava</h3>";}
      else {
        // když je $zprava prázdná - všechny údaje byly v pořádku
        // 4.2 - vytvoření proměnné z nezaškrtnutého zaškrtávacího pole - nezaškrtnutý checkbox nevytvoří proměnnou
        if(!isset($_POST["skladem"])){$_POST["skladem"]=0;}
        // 4.3 - připravení dotazu pro vložení záznamu do tabulky
        $dotaz=$spojeni->prepare("UPDATE vyrobky SET id_kategorie=?,id_vyrobce=?,nazev=?,cena=?,skladem=?,stav=?,popis=? WHERE id=?");
        // 4.4 - přiřazení vstupních parametrů - budou dosazeny za otazníky (první řetězec určuje typy hodnot: i-integer, s-string, d-double)
        $dotaz->bind_param("iisiissi",$_POST["kategorie"],$_POST["vyrobce"],$_POST["nazev"],$_POST["cena"],$_POST["skladem"],$_POST["stav"],$_POST["popis"],$_GET["id"]);
        // 4.5 - spuštění dotazu - v podmínce - pokud se provede, vrací true
        if($dotaz->execute()) {echo "<h2>Změny byly uloženy</h2> <a href='zobrazeni.php?id={$_GET["id"]}' class='tlacitko'>Zobrazit změny</a>"; }
        else {echo "<h2 class='chyba'>Změny nebyly uloženy</h2>\n".$dotaz->error;}
        // 4.6 uzavření dotazu
        $dotaz->close();
        // 4.7 - odkaz zpět na výpis
        echo "<p><a href='vypis_administrace.php'>«&nbsp;Zpět na výpis</a></p>";
        }
      }
    ?>
    </article>
  </div>
  </body>
</html>
